Contributing
============

Please use the `GitHub issue tracker <https://github.com/jeffgortmaker/pyblp/issues>`_ to report bugs or to request features. Contributions are welcome. Examples include:

- Code optimizations.
- Documentation improvements.
- Alternate formulations that have been implemented in the literature but not in PyBLP.
